@@ -13,6 +13,7 @@ from dacite import Config, from_dict
 
 from .code_mappings import (
     RoborockCategory,
+    RoborockCleanType,
     RoborockDockDustCollectionModeCode,
     RoborockDockErrorCode,
     RoborockDockTypeCode,
@@ -24,15 +25,21 @@ from .code_mappings import (
     RoborockFanSpeedS6Pure,
     RoborockFanSpeedS7,
     RoborockFanSpeedS7MaxV,
+    RoborockFanSpeedS8MaxVUltra,
+    RoborockFinishReason,
+    RoborockInCleaning,
     RoborockMopIntensityCode,
     RoborockMopIntensityP10,
     RoborockMopIntensityS5Max,
     RoborockMopIntensityS6MaxV,
     RoborockMopIntensityS7,
+    RoborockMopIntensityS8MaxVUltra,
     RoborockMopIntensityV2,
     RoborockMopModeCode,
     RoborockMopModeS7,
+    RoborockMopModeS8MaxVUltra,
     RoborockMopModeS8ProUltra,
+    RoborockStartType,
     RoborockStateCode,
 )
 from .const import (
@@ -44,6 +51,9 @@ from .const import (
     ROBOROCK_G10S_PRO,
     ROBOROCK_P10,
     ROBOROCK_Q7_MAX,
+    ROBOROCK_QREVO_MAXV,
+    ROBOROCK_QREVO_PRO,
+    ROBOROCK_QREVO_S,
     ROBOROCK_S4_MAX,
     ROBOROCK_S5_MAX,
     ROBOROCK_S6,
@@ -52,6 +62,7 @@ from .const import (
     ROBOROCK_S7,
     ROBOROCK_S7_MAXV,
     ROBOROCK_S8,
+    ROBOROCK_S8_MAXV_ULTRA,
     ROBOROCK_S8_PRO_ULTRA,
     SENSOR_DIRTY_REPLACE_TIME,
     SIDE_BRUSH_REPLACE_TIME,
@@ -404,7 +415,7 @@ class Status(RoborockBase):
     square_meter_clean_area: float | None = None
     error_code: RoborockErrorCode | None = None
     map_present: int | None = None
-    in_cleaning: int | None = None
+    in_cleaning: RoborockInCleaning | None = None
     in_returning: int | None = None
     in_fresh_state: int | None = None
     lab_status: int | None = None
@@ -550,6 +561,13 @@ class P10Status(Status):
     mop_mode: RoborockMopModeS8ProUltra | None = None
 
 
+@dataclass
+class S8MaxvUltraStatus(Status):
+    fan_power: RoborockFanSpeedS8MaxVUltra | None = None
+    water_box_mode: RoborockMopIntensityS8MaxVUltra | None = None
+    mop_mode: RoborockMopModeS8MaxVUltra | None = None
+
+
 ModelStatus: dict[str, type[Status]] = {
     ROBOROCK_S4_MAX: S4MaxStatus,
     ROBOROCK_S5_MAX: S5MaxStatus,
@@ -563,6 +581,13 @@ ModelStatus: dict[str, type[Status]] = {
     ROBOROCK_S8_PRO_ULTRA: S8ProUltraStatus,
     ROBOROCK_G10S_PRO: S7MaxVStatus,
     ROBOROCK_P10: P10Status,
+    # These likely are not correct,
+    # but i am currently unable to do my typical reverse engineering/ get any data from users on this,
+    # so this will be here in the mean time.
+    ROBOROCK_QREVO_S: P10Status,
+    ROBOROCK_QREVO_MAXV: P10Status,
+    ROBOROCK_QREVO_PRO: P10Status,
+    ROBOROCK_S8_MAXV_ULTRA: S8MaxvUltraStatus,
 }
 
 
@@ -601,9 +626,9 @@ class CleanRecord(RoborockBase):
     square_meter_area: float | None = None
     error: int | None = None
     complete: int | None = None
-    start_type: int | None = None
-    clean_type: int | None = None
-    finish_reason: int | None = None
+    start_type: RoborockStartType | None = None
+    clean_type: RoborockCleanType | None = None
+    finish_reason: RoborockFinishReason | None = None
     dust_collection_status: int | None = None
     avoid_count: int | None = None
     wash_count: int | None = None
@@ -829,3 +854,28 @@ class RoborockCategoryDetail(RoborockBase):
 @dataclass
 class ProductResponse(RoborockBase):
     category_detail_list: list[RoborockCategoryDetail]
+
+
+@dataclass
+class DyadProductInfo(RoborockBase):
+    sn: str
+    ssid: str
+    timezone: str
+    posix_timezone: str
+    ip: str
+    mac: str
+    oba: dict
+
+
+@dataclass
+class DyadSndState(RoborockBase):
+    sid_in_use: int
+    sid_version: int
+    location: str
+    bom: str
+    language: str
+
+
+@dataclass
+class DyadOtaNfo(RoborockBase):
+    mqttOtaData: dict
